@@ -64,7 +64,7 @@ QString FilterActionWithCommand::substituteCommandLineArgsFor(const KMime::Messa
     static const QRegularExpression re(QStringLiteral("%([0-9-]+)"));
 
     // search for '%n'
-    QRegularExpressionMatchIterator iter = re.globalMatch(result);
+    QRegularExpressionMatchIterator iter = re.globalMatchView(result);
     while (iter.hasNext()) {
         // and save the encountered 'n' in a list.
         bool ok = false;
@@ -254,7 +254,7 @@ FilterAction::ReturnCode FilterActionWithCommand::genericProcess(ItemContext &co
             if (uid != newUid) {
                 aMsg->setFrozen(false);
                 auto header = new KMime::Headers::Generic("X-UID");
-                header->fromUnicodeString(uid, "utf-8");
+                header->fromUnicodeString(uid);
                 aMsg->setHeader(header);
                 aMsg->assemble();
             }
